.. _user-reference:

#############################
Reference for content editors
#############################

.. note:: This is a new section in the django CMS documentation, and a priority
          for the project. If you'd like to contribute to it, we'd love to hear
          from you - join us on the #django-cms IRC channel on `freenode`_ or
          the `django-cms-developers`_ email list.

          If you don't have an IRC client, you can `join our IRC channel using the KiwiIRC web client
          <https://kiwiirc.com/client/irc.freenode.net/django-cms>`_, which works pretty well.

.. toctree::
    :maxdepth: 2

    page_admin
    frontend

.. _django-cms-developers: https://groups.google.com/group/django-cms-developers
.. _freenode : http://freenode.net/
